@@ -1,7 +1,7 @@
 #coding: utf-8
 from datetime import datetime
-from fabric.api import run, env, local, cd
-from fab_deploy.utils import run_as
+from fabric.api import run, env, cd
+from fab_deploy.utils import run_as, inside_virtualenv
 
 @run_as('root')
 def restart_apache():
@@ -11,14 +11,16 @@ def touch():
     """ Reloads source code by touching the wsgi file """
     run('touch %s/hosting/generated/django.wsgi' % env.conf['SRC_DIR'])
 
+@inside_virtualenv
 def pip_install(what='active', options=''):
     """ Installs pip requirements listed in reqs/<file>.txt file. """
-    run('pip install %s -E %s -r %s/reqs/%s.txt' % (options, env.conf['ENV_DIR'], env.conf['SRC_DIR'], what))
+    run('pip install %s -r %s/reqs/%s.txt' % (options, env.conf['SRC_DIR'], what))
     touch()
 
+@inside_virtualenv
 def pip_update(what='active', options='', restart=True):
     """ Updates pip requirements listed in reqs/<file>.txt file. """
-    run('pip install %s -U -E %s -r %s/reqs/%s.txt' % (options, env.conf['ENV_DIR'], env.conf['SRC_DIR'], what))
+    run('pip install %s -U -r %s/reqs/%s.txt' % (options, env.conf['SRC_DIR'], what))
     if restart:
         touch()
 
