@@ -2,13 +2,15 @@
 from __future__ import with_statement
 from fabric.api import env, cd, local, run, settings
 from fab_deploy.commands import mysqldump
+from fab_deploy.utils import inside_virtualenv
 
+@inside_virtualenv
 def manage(command, on_server=True):
     if on_server:
         with cd(env.conf['SRC_DIR']):
-            run ('%s/bin/python ./manage.py %s' % (env.conf['ENV_DIR'], command))
+            run('python ./manage.py '+ command)
     else:
-        local('./manage.py %s' % command)
+        local('./manage.py ' + command)
 
 def migrate(params='', do_backup=True):
     if do_backup:
@@ -22,10 +24,11 @@ def compress(params=''):
     with settings(warn_only=True):
         manage('synccompress %s' % params)
 
+@inside_virtualenv
 def test(what=''):
     with settings(warn_only=True):
         with cd(env.conf['SRC_DIR']):
-            run('source %s/bin/activate; ./runtests.sh %s' % (env.conf['ENV_DIR'], what))
+            run('./runtests.sh ' + what)
 
 def coverage():
     pass
