@@ -1,4 +1,5 @@
 from functools import wraps
+from fabric.context_managers import prefix
 from fabric.contrib.files import upload_template
 from fabric.api import env
 
@@ -45,3 +46,28 @@ def update_env():
     )
     defaults.update(env.conf)
     env.conf = defaults
+
+def virtualenv():
+    """
+    Context manager. Use it for perform actions inside virtualenv:
+
+        with virtualenv():
+            # virtualenv is active here
+
+    """
+    return prefix('source '+env.conf['ENV_DIR']+'/bin/activate')
+
+def inside_virtualenv(func):
+    """
+    Decorator. Use it for perform actions inside virtualenv:
+
+        @inside_virtualenv
+        def my_command():
+            # virtualenv is active here
+
+    """
+    @wraps(func)
+    def inner(*args, **kwargs):
+        with virtualenv():
+            return func(*args, **kwargs)
+    return inner
